[asterisk-commits] russell: branch russell/ais r80930 - in /team/russell/ais: include/asterisk/ ...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Sun Aug 26 00:18:35 CDT 2007


Author: russell
Date: Sun Aug 26 00:18:34 2007
New Revision: 80930

URL: http://svn.digium.com/view/asterisk?view=rev&rev=80930
Log:
change server_args to ast_server_args

Modified:
    team/russell/ais/include/asterisk/server.h
    team/russell/ais/main/http.c
    team/russell/ais/main/manager.c
    team/russell/ais/main/server.c

Modified: team/russell/ais/include/asterisk/server.h
URL: http://svn.digium.com/view/asterisk/team/russell/ais/include/asterisk/server.h?view=diff&rev=80930&r1=80929&r2=80930
==============================================================================
--- team/russell/ais/main/http.c (original)
+++ team/russell/ais/main/http.c Sun Aug 26 00:18:34 2007
@@ -30,7 +30,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision$")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 80925 $")
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -76,7 +76,7 @@
 /*!
  * we have up to two accepting threads, one for http, one for https
  */
-static struct server_args http_desc = {
+static struct ast_server_args http_desc = {
 	.accept_fd = -1,
 	.master = AST_PTHREADT_NULL,
 	.tls_cfg = NULL,
@@ -86,7 +86,7 @@
 	.worker_fn = httpd_helper_thread,
 };
 
-static struct server_args https_desc = {
+static struct ast_server_args https_desc = {
 	.accept_fd = -1,
 	.master = AST_PTHREADT_NULL,
 	.tls_cfg = &http_tls_cfg,

Modified: team/russell/ais/main/manager.c
URL: http://svn.digium.com/view/asterisk/team/russell/ais/main/manager.c?view=diff&rev=80930&r1=80929&r2=80930
==============================================================================
--- team/russell/ais/main/manager.c (original)
+++ team/russell/ais/main/manager.c Sun Aug 26 00:18:34 2007
@@ -43,7 +43,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision$")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 80925 $")
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -3230,7 +3230,7 @@
 }
 
 struct ast_tls_config ami_tls_cfg;
-static struct server_args ami_desc = {
+static struct ast_server_args ami_desc = {
         .accept_fd = -1,
         .master = AST_PTHREADT_NULL,
         .tls_cfg = NULL, 
@@ -3241,7 +3241,7 @@
         .worker_fn = session_do,	/* thread handling the session */
 };
 
-static struct server_args amis_desc = {
+static struct ast_server_args amis_desc = {
         .accept_fd = -1,
         .master = AST_PTHREADT_NULL,
         .tls_cfg = &ami_tls_cfg, 

Modified: team/russell/ais/main/server.c
URL: http://svn.digium.com/view/asterisk/team/russell/ais/main/server.c?view=diff&rev=80930&r1=80929&r2=80930
==============================================================================
--- team/russell/ais/main/server.c (original)
+++ team/russell/ais/main/server.c Sun Aug 26 00:18:34 2007
@@ -76,7 +76,7 @@
 
 void *server_root(void *data)
 {
-	struct server_args *desc = data;
+	struct ast_server_args *desc = data;
 	int fd;
 	struct sockaddr_in sin;
 	socklen_t sinlen;
@@ -184,7 +184,7 @@
 /*! A generic client routine for a TCP client
  *  and starts a thread for handling accept()
  */
-struct server_instance *client_start(struct server_args *desc)
+struct server_instance *client_start(struct ast_server_args *desc)
 {
 	int flags;
 	struct server_instance *ser;
@@ -251,7 +251,7 @@
  * accept().
  */
 
-void server_start(struct server_args *desc)
+void server_start(struct ast_server_args *desc)
 {
 	int flags;
 	int x = 1;




More information about the asterisk-commits mailing list
--- team/russell/ais/include/asterisk/server.h (original)
+++ team/russell/ais/include/asterisk/server.h Sun Aug 26 00:18:34 2007
@@ -72,7 +72,7 @@
 /*!
  * The following code implements a generic mechanism for starting
  * services on a TCP or TLS socket.
  * The service is configured in the struct server_args, and
  * then started by calling server_start(desc) on the descriptor.
  * server_start() first verifies if an instance of the service is active,
  * and in case shuts it down. Then, if the service must be started, creates
@@ -94,7 +94,7 @@
  *
  * NOTE: in order to let other parts of asterisk use these services,
  * we need to do the following:
  * + move struct server_instance and struct server_args to
  * a common header file, together with prototypes for
  * server_start() and server_root().
  */
@@ -109,13 +109,13 @@
 //	iint (*ssl_setup)(SSL *);
 	int client;
 	struct sockaddr_in requestor;
-	struct server_args *parent;
+	struct ast_server_args *parent;
 };
 
 /*!
  * arguments for the accepting thread
  */
-struct server_args {
+struct ast_server_args {
 	struct sockaddr_in sin;
 	struct sockaddr_in oldsin;
 	struct ast_tls_config *tls_cfg; /* points to the SSL configuration if any */
@@ -128,10 +128,10 @@
 	const char *name;
 };
 
-struct server_instance *client_start(struct server_args *desc);
+struct server_instance *client_start(struct ast_server_args *desc);
 
 void *server_root(void *);
-void server_start(struct server_args *desc);
+void server_start(struct ast_server_args *desc);
 int ssl_setup(struct ast_tls_config *cfg);
 
 void *ast_make_file_from_fd(void *data);
@@ -72,7 +72,7 @@
  * The following code implements a generic mechanism for starting
  * services on a TCP or TLS socket.
- * The service is configured in the struct server_args, and
+ * The service is configured in the struct ast_server_args, and
  * then started by calling server_start(desc) on the descriptor.
  * server_start() first verifies if an instance of the service is active,
@@ -94,7 +94,7 @@
  * NOTE: in order to let other parts of asterisk use these services,
  * we need to do the following:
- * + move struct server_instance and struct server_args to
+ * + move struct server_instance and struct ast_server_args to
  * a common header file, together with prototypes for
  * server_start() and server_root().

Modified: team/russell/ais/main/http.c
URL: http://svn.digium.com/view/asterisk/team/russell/ais/main/http.c?view=diff&rev=80930&r1=80929&r2=80930
==============================================================================